<?php

namespace Drupal\syncloud\Hook;

/**
 * @file
 * Contains \Drupal\syncloud\Hook.
 */

use Drupal\Core\Entity\EntityInterface;
use GuzzleHttp\Client;
use GuzzleHttp\Exception\ClientException;
use GuzzleHttp\Exception\GuzzleException;
use GuzzleHttp\Exception\RequestException;
use GuzzleHttp\Exception\ConnectException;

/**
 * Class PageAttachmentsAlter.
 */
class ContactMessageInsert {
  /**
   * Hook.
   */
  public static function hook(EntityInterface $entity) {
    $syn_storage = \Drupal::entityTypeManager()->getStorage('syn');
    $form_id = $entity->getContactForm()->id();
    $ip = \Drupal::request()->getClientIp();
    $path = \Drupal::service('path.current')->getPath();
    $syn_array = [
      'name' => $ip . '--' . $form_id,
      'ip' => $ip,
      'host' => \Drupal::request()->getHost(),
      'scheme' => \Drupal::request()->getScheme(),
      'type' => $form_id,
      'message' => $entity->id(),
      'city' => [],
      'url' => \Drupal::request()->getSchemeAndHttpHost() . \Drupal::service('path_alias.manager')->getAliasByPath($path),
    ];
    $syn = $syn_storage->create($syn_array);
    $syn_storage->save($syn);
    \Drupal::service('syncloud.queue')->queuePush($entity->id(), $syn->id());

    \Drupal::logger(__CLASS__)->notice("RUN");
    self::guzzlePushQueue();
  }

  /**
   * Hook.
   */
  private static function guzzlePushQueue() {
    $host = \Drupal::request()->getSchemeAndHttpHost();
    $client = new Client([
      'base_uri' => $host,
      'timeout'  => 0.1,
    ]);
    try {
      $response = $client->get("$host/syncloud/queue");
      $message = $response->getStatusCode();
    } catch (ConnectException $e) {
      $message = 'ConnectException ' . $e->getMessage();
    } catch (RequestException $e) {
      $message = 'RequestException ' . $e->getMessage();
    } catch (ClientException $e) {
      $message = 'ClientException ' . $e->getMessage();
    } catch (GuzzleException $e) {
      $message = 'GuzzleException ' . $e->getMessage();
    }
    \Drupal::logger(__CLASS__)->notice("RequestException::$message");
    return $message;
  }


}
