<?php

namespace Drupal\syncloud\Service;

use Drupal\user\Entity\User;

/**
 * Class Connector.
 */
class Queue {
  /**
   * Init funciton.
   */
  public function __construct() {
    $this->storage = \Drupal::entityTypeManager()->getStorage('contact_message');
    $this->syn_storage = \Drupal::entityTypeManager()->getStorage('syn');
  }

  /**
   * Push entity to queue.
   */
  public function queuePush(int $id, $syn_id) {
    $queue = \Drupal::queue('syncloud_queue');
    $queue->createQueue();
    $queue->createItem([
      'id' => $id,
      'syn_id' => $syn_id,
    ]);
  }

  /**
   * Process queue.
   */
  public function queueProcess() {
    $end = time() + 30;
    $queue = \Drupal::queue('syncloud_queue');
    while (time() < $end && ($item = $queue->claimItem())) {
      $entity = $this->storage->load($item->data['id']);
      $syn = $this->syn_storage->load($item->data['syn_id']);
      $type = $entity->getEntityType()->id();

      $form_id = $entity->getContactForm()->id();
      $config =  \Drupal::configFactory()->get('syncloud.settings');
      if ($config->get('telegram-int')) {
        $uuid = \Drupal::state()->get('syncloud.uuid');
        $msg = [
          'ip' => $syn->ip->value,
          'type' => $form_id,
          'host' => $syn->host->value,
          'url' => $syn->url->value,
        ];
        foreach ($entity->getFields() as $name => $field) {
          $msg['message--' . $name] = $field->getString();
        }
        \Drupal::service('syncloud.mqtt')->run()->publish("\$telega/syncloud/$uuid/event/contact-message", json_encode($msg));
      }
      $queue->deleteItem($item);
    }
  }
}
